@@ -3,6 +3,8 @@ from .models import *
 from django.contrib.auth import get_user_model
 from django.contrib.auth.admin import UserAdmin as BaseUserAdmin
 
+from .models.config import Config
+
 
 class UserAdmin(BaseUserAdmin):
     fieldsets = (
@@ -51,6 +53,7 @@ admin.site.register(Cart)
 admin.site.register(Conversation)
 admin.site.register(Message)
 admin.site.register(Disco)
+admin.site.register(BusinessUnit)
 admin.site.register(Documentation)
 admin.site.register(Document)
 admin.site.register(Expertise)
@@ -58,7 +61,6 @@ admin.site.register(MeansOfIdentification)
 admin.site.register(MeterRequest)
 admin.site.register(NextOfKin)
 admin.site.register(PaymentVendor)
-admin.site.register(PaymentType)
 admin.site.register(Payment)
 admin.site.register(Product)
 admin.site.register(Purchase)
@@ -73,3 +75,4 @@ admin.site.register(WorkOrder)
 admin.site.register(WorkOrderMaterial)
 admin.site.register(WorkOrderService)
 admin.site.register(WorkOrderStatus)
+admin.site.register(Config)
